@@ -12,7 +12,6 @@ from pyhocon import ConfigFactory, ConfigTree
 from sqlalchemy.engine.url import make_url
 
 from databuilder.extractor import sql_alchemy_extractor
-from databuilder.extractor.sql_alchemy_extractor import SQLAlchemyExtractor
 from databuilder.extractor.base_extractor import Extractor
 from databuilder.models.table_metadata import ColumnMetadata, TableMetadata
 
@@ -26,7 +25,7 @@ class PrestoViewMetadataExtractor(Extractor):
     """
     # SQL statement to extract View metadata
     # {where_clause_suffix} could be used to filter schemas
-    SQL_STATEMENT = """
+    DEFAULT_SQL_STATEMENT = """
     SELECT t.TBL_ID, d.NAME as `schema`, t.TBL_NAME name, t.TBL_TYPE, t.VIEW_ORIGINAL_TEXT as view_original_text
     FROM TBLS t
     JOIN DBS d ON t.DB_ID = d.DB_ID
@@ -35,6 +34,19 @@ class PrestoViewMetadataExtractor(Extractor):
     ORDER BY t.TBL_ID desc;
     """
 
+    DEFAULT_POSTGRES_SQL_STATEMENT = """
+    SELECT t."TBL_ID",
+    d."NAME" as "schema",
+    t."TBL_NAME" as name,
+    t."TBL_TYPE",
+    t."VIEW_ORIGINAL_TEXT" as view_original_text
+    FROM "TBLS" t
+    JOIN "DBS" d ON t."DB_ID" = d."DB_ID"
+    WHERE t."VIEW_EXPANDED_TEXT" = '/* Presto View */'
+    {where_clause_suffix}
+    ORDER BY t."TBL_ID" desc;
+    """
+
     # Presto View data prefix and suffix definition:
     # https://github.com/prestodb/presto/blob/43bd519052ba4c56ff1f4fc807075637ab5f4f10/presto-hive/src/main/java/com/facebook/presto/hive/HiveUtil.java#L153-L154
     PRESTO_VIEW_PREFIX = '/* Presto View: '
@@ -51,18 +63,7 @@ class PrestoViewMetadataExtractor(Extractor):
         conf = conf.with_fallback(PrestoViewMetadataExtractor.DEFAULT_CONFIG)
         self._cluster = conf.get_string(PrestoViewMetadataExtractor.CLUSTER_KEY)
 
-        LOGGER.info(conf)
-        LOGGER.info(type(conf))
-        for item in conf.items():
-            LOGGER.info(item)
-        LOGGER.info(conf.get("extractor").get("sqlalchemy").get("conn_string"))    
-        LOGGER.info(conf.get("extractor.sqlalchemy.conn_string"))
-        conn_string = conf.get_string(SQLAlchemyExtractor.CONN_STRING)
-        LOGGER.info(conn_string)
-        url = make_url(conn_string)
-        LOGGER.info(url.drivername.lower())
-
-        self.sql_stmt = PrestoViewMetadataExtractor.SQL_STATEMENT.format(
+        self.sql_stmt = self._choose_default_sql_stm(conf).format(
             where_clause_suffix=conf.get_string(PrestoViewMetadataExtractor.WHERE_CLAUSE_SUFFIX_KEY))
 
         LOGGER.info('SQL for hive metastore: %s', self.sql_stmt)
@@ -70,6 +71,13 @@ class PrestoViewMetadataExtractor(Extractor):
         self._alchemy_extractor = sql_alchemy_extractor.from_surrounding_config(conf, self.sql_stmt)
         self._extract_iter: Union[None, Iterator] = None
 
+    def _choose_default_sql_stm(self, conf: ConfigTree) -> str:
+        url = make_url(conf.get_string("extractor.sqlalchemy.conn_string"))
+        if url.drivername.lower() in ['postgresql', 'postgres']:
+            return self.DEFAULT_POSTGRES_SQL_STATEMENT
+        else:
+            return self.DEFAULT_SQL_STATEMENT
+
     def close(self) -> None:
         if getattr(self, '_alchemy_extractor', None) is not None:
             self._alchemy_extractor.close()
